package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.PolicyGuide;

/**
 * 政策指南Mapper接口
 * 
 * @author boman
 * @date 2022-06-16
 */
public interface PolicyGuideMapper 
{
    /**
     * 查询政策指南
     * 
     * @param policyId 政策指南主键
     * @return 政策指南
     */
    public PolicyGuide selectPolicyGuideByPolicyId(Long policyId);

    /**
     * 查询政策指南列表
     * 
     * @param policyGuide 政策指南
     * @return 政策指南集合
     */
    public List<PolicyGuide> selectPolicyGuideList(PolicyGuide policyGuide);

    /**
     * 新增政策指南
     * 
     * @param policyGuide 政策指南
     * @return 结果
     */
    public int insertPolicyGuide(PolicyGuide policyGuide);

    /**
     * 修改政策指南
     * 
     * @param policyGuide 政策指南
     * @return 结果
     */
    public int updatePolicyGuide(PolicyGuide policyGuide);

    /**
     * 删除政策指南
     * 
     * @param policyId 政策指南主键
     * @return 结果
     */
    public int deletePolicyGuideByPolicyId(Long policyId);

    /**
     * 批量删除政策指南
     * 
     * @param policyIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePolicyGuideByPolicyIds(Long[] policyIds);
}
